@@ -1,4 +1,3 @@
-from bergen.auths.types import HerreConfig
 from oauthlib.oauth2.rfc6749.clients.legacy_application import LegacyApplicationClient
 from oauthlib.oauth2.rfc6749.clients.mobile_application import MobileApplicationClient
 import requests
@@ -14,7 +13,7 @@ class ImplicitError(Exception):
 class LegacyApplication(BaseAuthBackend):
 
 
-    def __init__(self, config: HerreConfig, username=None, password=None, **kwargs) -> None:
+    def __init__(self, config, username=None, password=None, **kwargs) -> None:
         super().__init__(config, **kwargs)
         self.username = username
         self.password = password
