@@ -1,5 +1,5 @@
 from .unassign import UnassignMessage
 from .unassign_critical import UnassignCriticalMessage
-from .unassign_progress import UnassignProgressMessage
+from .unassign_log import UnassignLogMessage
 from .bounced_unassign import BouncedUnassignMessage
 from .unassign_done import UnassignDoneMessage
\ No newline at end of file
