@@ -15,26 +15,31 @@ registry = {
     PROVIDE_DONE:  ProvideDoneMessage,
     BOUNCED_PROVIDE: BouncedProvideMessage,
     PROVIDE_CRITICAL: ProvideCriticalMessage,
-    PROVIDE_PROGRESS: ProvideProgressMessage,
+    PROVIDE_LOG: ProvideLogMessage,
+    PROVIDE_TRANSITION: ProvideTransitionMessage,
     PROVIDE: ProvideMessage,
 
     UNPROVIDE_DONE:  UnprovideDoneMessage,
     BOUNCED_UNPROVIDE: BouncedUnprovideMessage,
     UNPROVIDE_CRITICAL: UnprovideCriticalMessage,
-    UNPROVIDE_PROGRESS: UnprovideProgressMessage,
+    UNPROVIDE_ERROR: UnprovideErrorMessage,
+    UNPROVIDE_LOG: UnprovideLogMessage,
     UNPROVIDE: UnprovideMessage,
 
     RESERVE: ReserveMessage,
     BOUNCED_RESERVE: BouncedReserveMessage,
     BOUNCED_FORWARDED_RESERVE: BouncedForwardedReserveMessage,
     RESERVE_CRITICAL: ReserveCriticalMessage,
-    RESERVE_PROGRESS: ReserveProgressMessage,
+    RESERVE_LOG: ReserveLogMessage,
     RESERVE_DONE: ReserveDoneMessage,
+    RESERVE_ACTIVE: ReserveActiveMessage,
+    RESERVE_WAITING: ReserveWaitingMessage,
+    RESERVE_TRANSITION: ReserveTransitionMessage,
 
     UNRESERVE: UnreserveMessage,
     BOUNCED_UNRESERVE: BouncedUnreserveMessage,
     UNRESERVE_CRITICAL: UnreserveCriticalMessage,
-    UNRESERVE_PROGRESS: UnreserveProgressMessage,
+    UNRESERVE_LOG: UnreserveLogMessage,
     UNRESERVE_DONE: UnreserveDoneMessage,
 
     ASSIGN: AssignMessage,
@@ -42,7 +47,7 @@ registry = {
     BOUNCED_FORWARDED_ASSIGN: BouncedForwardedAssignMessage,
     ASSIGN_CRITICAL: AssignCriticalMessage,
     ASSIGN_CANCELLED: AssignCancelledMessage,
-    ASSIGN_PROGRES: AssignProgressMessage,
+    ASSIGN_LOG: AssignLogMessage,
     ASSIGN_RETURN: AssignReturnMessage,
     ASSIGN_DONE: AssignDoneMessage,
     ASSIGN_YIELD: AssignYieldsMessage,
@@ -50,7 +55,7 @@ registry = {
     UNASSIGN: UnassignMessage,
     BOUNCED_UNASSIGN: BouncedUnassignMessage,
     UNASSIGN_CRITICAL: UnassignCriticalMessage,
-    UNASSIGN_PROGRES: UnassignProgressMessage,
+    UNASSIGN_LOG: UnassignLogMessage,
     UNASSIGN_DONE: UnassignDoneMessage,
 
     ACTIVATE_POD: ActivatePodMessage,
