@@ -26,7 +26,7 @@ def build_assign_message(reference, reservation, args, kwargs, with_progress=Fal
 
 
 
-def build_unassign_messsage(reference, assignation, with_progress=False, bounced=None):
+def build_unassign_messsage(reference, assignation, with_progress=False, bounced=None, persist=False):
     assert reference is not None, "Must have a reference"
     data= {
                                         "assignation": assignation
@@ -35,7 +35,8 @@ def build_unassign_messsage(reference, assignation, with_progress=False, bounced
     meta={
                                     "reference": reference, 
                                     "extensions": {
-                                        "with_progress": with_progress
+                                        "with_progress": with_progress,
+                                        "persist": persist
                                     }
     }
 
