@@ -7,6 +7,7 @@ from bergen.query import TypedGQL
 import logging
 from bergen.console import console
 
+logger = logging.getLogger(__name__)
 
 class AIOHttpWard(ServiceWard):
     can_subscribe = False
@@ -32,9 +33,10 @@ class AIOHttpWard(ServiceWard):
         query_node = the_query.query
         try:
             async with self.async_session.post(self._graphql_endpoint, json={"query": query_node, "variables": variables}) as resp:
-
+                
                 if resp.status == 200:
                     result = await resp.json() 
+                    logger.debug(f"Received Reply {result}")
 
                     if "errors" in result:
                         raise GraphQLException(f"Ward {self._graphql_endpoint}:" + str(result["errors"]))
