@@ -49,10 +49,9 @@ class BaseWard(ABC):
 
 
     async def run(self, gql: TypedGQL, variables: dict = {}):
-        print("Called")
         try:
             return await self.pass_async(gql, variables=variables)
-            
+
         except TokenExpired:
             console.print_exception()
 
@@ -64,6 +63,10 @@ class BaseWard(ABC):
 
             return await self.pass_async(gql, variables=variables)
 
+        except:
+            console.print_exception(show_locals=True)
+            raise
+
 
 
     @abstractmethod
